@@ -21,6 +21,7 @@
 
 #include <qcommandlineparser.h>
 #include <qapplication.h>
+#include <qicon.h>
 
 #include <kaboutdata.h>
 #include <KCrash>
@@ -48,17 +49,16 @@
 
 int main(int argc, char *argv[])
 {
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-
     QApplication qapp(argc, argv);
 
     KLocalizedString::setApplicationDomain("kmix");
+    KCrash::setDrKonqiEnabled(true);
 
     KCrash::initialize();
 
     KAboutData aboutData("kmix", i18n("KMix"),
                          KMIX_VERSION, i18n("KMix - KDE's full featured mini mixer"), KAboutLicense::GPL,
-                         i18n("(c) 1996-2013 The KMix Authors"));
+                         i18n("(c) 1996-2024 The KMix Authors"));
 
    // Author Policy: Long-term maintainers and backend writers/maintainers go in the Authors list.
    aboutData.addAuthor(i18n("Christian Esken")   , i18n("Original author and current maintainer"), "esken@kde.org");
@@ -71,7 +71,7 @@ int main(int argc, char *argv[])
 // aboutData.addAuthor(i18n("Nick Lopez")        , i18n("Initial ALSA port"), "kimo_sabe@usa.net");
 
    // Credit Policy: Authors who did a discrete part, like the Dataengine, OSD, help on specific platforms or soundcards.
-   aboutData.addCredit(i18n("Jonathan Marten")   , i18n("KF5 hotplugging, ALSA/OSS volume feedback, GUI improvements"), "jonathan.marten@kdemail.net");
+   aboutData.addCredit(i18n("Jonathan Marten")   , i18n("KF5 hotplugging, ALSA/OSS volume feedback, GUI improvements, KF6 port"), "jonathan.marten@kdemail.net");
    aboutData.addCredit(i18n("Igor Poboiko")      , i18n("Plasma Dataengine"), "igor.poboiko@gmail.com");
    aboutData.addCredit(i18n("Stefan Schimanski") , i18n("Temporary maintainer"), "schimmi@kde.org");
    aboutData.addCredit(i18n("Sebestyen Zoltan")  , i18n("*BSD fixes"), "szoli@digo.inf.elte.hu");
@@ -109,6 +109,10 @@ int main(int argc, char *argv[])
                            "http://www.opensound.com/");
 #endif
 
+    // Set the window icon explicitly for the "About <application>"
+    // dialogue and the "About <application>" menu action.
+    QGuiApplication::setWindowIcon(QIcon::fromTheme("kmix"));
+
    KAboutData::setApplicationData(aboutData);
 
    // Set up and parse the command line now, so as to be able to respond to
@@ -119,6 +123,7 @@ int main(int argc, char *argv[])
    parser.addOption(QCommandLineOption("failsafe", i18n("Start KMix in failsafe mode.")));
    parser.addOption(QCommandLineOption("backends", i18n("A list of backends to use (for testing only)."), i18n("name[,name...]"), QString()));
    parser.addOption(QCommandLineOption("multidriver", i18n("Enable the (experimental) multiple driver mode.")));
+   parser.addOption(QCommandLineOption("nosystemtray", i18n("Do not show the system tray volume control.")));
    parser.process(qapp);
 
    // Implement running as a unique application
